California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 061- STATE PRESCRIPTION DRUG PURCHASES. PRICING STANDARDS. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1379198 | NO ON PROP 61 - CALIFORNIANS AGAINST THE DECEPTIVE RX PROPOSITION, A COALITION OF VETERANS DOCTORS PATIENT ADVOCATES SENIORS TAXPAYERS AND MEMBERS OF PHARMACEUTICAL RESEARCH AND MANUFACTURERS OF AMER. | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1376791 | YES ON PROP 61, CALIFORNIANS FOR LOWER DRUG PRICES, WITH MAJOR FUNDING BY AIDS HEALTHCARE FOUNDATION AND CALIFORNIA NURSES ASSOCIATION PAC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1387641 | CONSUMER WATCHDOG CAMPAIGN - YES ON 61, MAJOR FUNDING BY YES ON PROP 61, CALIFORNIANS FOR LOWER DRUG PRICES, WITH MAJOR FUNDING BY AIDS HEALTHCARE FOUNDATION AND CALIFORNIA NURSES ASSOCIATION PAC | SUPPORT